@@ -1,20 +1,20 @@
+import decimal
 import itertools
 import json
 import logging
 import os
 import time
 import traceback
-from typing import Optional
 import uuid
 from contextlib import contextmanager
-import decimal
+from typing import Optional
 
 
 class DecimalEncoder(json.JSONEncoder):
     def default(self, o):
         if isinstance(o, decimal.Decimal):
             return str(o)
-        return super(DecimalEncoder, self).default(o)
+        return super().default(o)
 
 
 class Base:
@@ -139,7 +139,7 @@ class Tracer(Base):
         if kwargs.get('log', True):
             data_serilized = self.serilizer_data(data)
             if data_serilized is not None:
-                logging.info('instrumenting-trace {}'.format(data_serilized))
+                logging.info(f'instrumenting-trace {data_serilized}')
             else:
                 logging.error('instrumenting-error-trace error by convert')
 
@@ -193,7 +193,7 @@ class DjangoTracer(Tracer):
         if kwargs.get('log', True):
             data_serilized = self.serilizer_data(data, env=kwargs.get('env'))
             if data_serilized is not None:
-                logging.info('instrumenting-trace {}'.format(data_serilized))
+                logging.info(f'instrumenting-trace {data_serilized}')
             else:
                 logging.error('instrumenting-error-trace error by convert')
 
@@ -223,4 +223,4 @@ class DjangoViewTracer(DjangoTracer):
         except Exception as e:
             if self.env != 'production':
                 raise e
-            return {}
\ No newline at end of file
+            return {}
